@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 from .client import Client
 
-
 """
 Deployment Class
 """
@@ -13,24 +12,26 @@ class Deploy(Client):
     :return string
     """
     def list(self, repository="", environment=""):
-        url = "deployments?limit=20&repository_id=%s&environment_id=%s" % \
-              (repository, environment)
+        url = "deployments?limit=20"
+        url += "&repository_id=%s" % repository
+        url += "&environment_id=%s" % environment
 
-        return super(Deploy, self)\
-            .get(url)
+        return super(Deploy, self).get(url)
 
     """
     Get deployment by id
     :return string
     """
     def get(self, deploy):
-        return super(Deploy, self)\
-            .get("deployments/%s" % deploy)
+        url = "deployments/%s" % deploy
+
+        return super(Deploy, self).get(url)
 
     """
     Trigger a deploy
     :return string
     """
     def trigger(self, environment):
-        return super(Deploy, self)\
-            .post("deployments", {'environment_id': environment})
+        args = ("deployments", {'environment_id': environment})
+
+        return super(Deploy, self).post(*args)
