@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 from .client import Client
 
-
 """
 Environment Class
 """
@@ -13,13 +12,15 @@ class Environment(Client):
     :return string
     """
     def list(self, repository=""):
-        return super(Environment, self)\
-            .get("environments?repository_id=%s" % repository)
+        url = "environments?repository_id=%s" % repository
+
+        return super(Environment, self).get(url)
 
     """
     Get an environment
     :return string
     """
     def get(self, environment):
-        return super(Environment, self)\
-            .get("environments/%s" % environment)
+        url = "environments/%s" % environment
+
+        return super(Environment, self).get(url)
